@@ -6,7 +6,7 @@ import threading
 import time
 import warnings
 from functools import wraps
-from typing import List, Union, Callable
+from typing import List, Union, Callable, Tuple
 
 from .basic import Action, ActionList
 from ..mixin import Status, Configuration, InstanceRegistry
@@ -23,6 +23,7 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
                  *args,
                  configuration_name: str = None,
                  next_action: Union[str, 'ConfiguredAction'] = None,
+                 condition: Union[Tuple[object, str], Callable] = None,
                  aliases: List[str] = None,
                  **kwargs,
                  ):
@@ -36,6 +37,9 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
         :param configuration_name: optional name for the configuration (for key retrieval). This can be a useful way of
             differentiating specific configurations of an action if there are multiple configurations for that action.
         :param next_action: optional next action for sequence building
+        :param condition: a condition evaulation which must be True for the execution to proceed. This may either be
+            a callable which can be evaluated, or a pointer to some attribute of an object which will be checked
+            at runtime for a bool.
         :param kwargs: keyword arguments for the action
         :param aliases: list of aliases which refer to the configured action instance
         """
@@ -50,6 +54,7 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
         self.aliases: List[str] = aliases
         # register action and store attribute
         self.action = action
+        self.condition: Union[Tuple[object, str], Callable, None] = condition
         Configuration.__init__(
             self,
             *self.action.default_args,
@@ -181,6 +186,16 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
         if alias in self.aliases:
             self.aliases.remove(alias)
 
+    def evaluate_condition(self) -> bool:
+        """Evaluates the condition (if specified) for the configuration"""
+        if self.condition is None:
+            return True
+        elif type(self.condition) is tuple:
+            obj, attr = self.condition
+            return getattr(obj, attr)
+        else:
+            return self.condition()
+
     @staticmethod
     def _match_instance_key(inst: "ConfiguredAction", identifier: str) -> bool:
         """
@@ -368,11 +383,12 @@ class ConfigurableInstance:
     def _register_instance_actions(self):
         """registers instance actions as ConfiguredActions"""
         for method_name in self.methods_to_register:
-            setattr(
-                self,
-                method_name,
-                ConfiguredAction(getattr(self, method_name))
-            )
+            if isinstance(getattr(self, method_name), ConfiguredAction) is False:
+                setattr(
+                    self,
+                    method_name,
+                    ConfiguredAction(getattr(self, method_name))
+                )
 
 
 def ensure_triggered(fn: Callable):
@@ -421,6 +437,7 @@ class TrackedAction(InstanceRegistry, Configuration, Status):
         self._time_started = None
         self._time_completed = None
         self._action_return = None
+        self._condition_evaluation = None
 
     def __call__(self, *args, **kwargs):
         """
@@ -448,11 +465,17 @@ class TrackedAction(InstanceRegistry, Configuration, Status):
         self.freeze = True   # freeze settings
         self._time_started = time.time()  # set start time
         try:
-            self._action_return = self.configuration.action(
-                *self.args,
-                **self.kwargs
-            )
-            logger.debug(f'action {self.configuration.action.name} completed successfully')
+            self._condition_evaluation = self._configuration.evaluate_condition()
+            if self._condition_evaluation is False:
+                logger.debug(
+                    f'condition for action {self.configuration.action.name} evaluated to False, bypassing execution'
+                )
+            else:
+                self._action_return = self.configuration.action(
+                    *self.args,
+                    **self.kwargs
+                )
+                logger.debug(f'action {self.configuration.action.name} completed successfully')
         except Exception as e:
             logger.error(f'error encountered when executing action {self.configuration.name}: {e}')
             self.error = True
@@ -593,6 +616,7 @@ class TrackedAction(InstanceRegistry, Configuration, Status):
                 out['error_details'] = str(self.error_details)
             else:  # if completed and no error, include the method return
                 out['action_return'] = self.action_return
+                out['condition_evaluation'] = self._condition_evaluation
         return out
 
     def copy_configuration(self) -> "TrackedAction":
