@@ -241,7 +241,9 @@ class ActionTimePoint(ExecutionSequence, TimePoint):
         if self.sequence_time_started is None:
             raise ValueError(f'sequence_start_time is not set for the {self.__class__.__name__} instance')
         return {
-            action.configuration.name: action.time_started - self.sequence_time_started for action in self.args
+            action.configuration.name: action.time_started - self.sequence_time_started
+            for action in self.args
+            if action.time_started is not None
         }
 
     def copy_configuration(self) -> "ActionTimePoint":
