@@ -198,6 +198,10 @@ def return_false() -> bool:
     return False
 
 
+class ConditionClass:
+    flag = False
+
+
 class TestConfiguredAction(unittest.TestCase):
     def test_instance_by_id(self):
         # todo docstrings suggest that only the UUID can be used
@@ -270,6 +274,39 @@ class TestConfiguredAction(unittest.TestCase):
         self.assertEqual(TrackedAction,
                          type(tracked))
 
+    def test_conditional_configured_action(self):
+        """tests the conditional configured action setup"""
+        flag = False
+        def evaluator():
+            return flag
+
+        cond = ConfiguredAction(return_str, condition=evaluator)
+        track_1 = cond.get_tracked_from_config()
+        track_1()
+        self.assertEqual(track_1.status_code, 3)
+        self.assertIsNone(track_1.action_return, "ensure that the action didn't run")
+        flag = True
+        track_2 = cond.get_tracked_from_config()
+        track_2()
+        self.assertEqual(track_2.status_code, 3)
+        self.assertEqual(track_2.action_return, 'metal', "ensure that the action executed")
+        output = track_2.as_dict()
+        self.assertEqual(output['condition_evaluation'], True, "ensure output to dictionary")
+
+    def test_conditional_configured_accession(self):
+        """tests the configuredaction condition where the condition is a class flag"""
+        cond_class = ConditionClass()
+        cond_conf_1 = ConfiguredAction(return_str, condition=(cond_class, 'flag'))
+        track_1 = cond_conf_1.get_tracked_from_config()
+        track_1()
+        self.assertEqual(track_1.status_code, 3)
+        self.assertIsNone(track_1.action_return, "ensure that the action didn't run")
+        cond_class.flag = True
+        track_2 = cond_conf_1.get_tracked_from_config()
+        track_2()
+        self.assertEqual(track_2.status_code, 3)
+        self.assertEqual(track_2.action_return, 'metal', "ensure that the action executed")
+
 
 class TestEvalAction(unittest.TestCase):
     def setUp(self) -> None:
